Class: Azure::DataFactory::Mgmt::V2018_06_01::DataFlows

Inherits:
Object
  • Object
show all
Includes:
MsRestAzure
Defined in:
lib/2018-06-01/generated/azure_mgmt_data_factory/data_flows.rb

Overview

The Azure Data Factory V2 management API provides a RESTful set of web services that interact with Azure Data Factory V2 services.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(client) ⇒ DataFlows

Creates and initializes a new instance of the DataFlows class.

Parameters:

  • client

    service class for accessing basic functionality.



18
19
20
# File 'lib/2018-06-01/generated/azure_mgmt_data_factory/data_flows.rb', line 18

def initialize(client)
  @client = client
end

Instance Attribute Details

#clientDataFactoryManagementClient (readonly)

Returns reference to the DataFactoryManagementClient.

Returns:



23
24
25
# File 'lib/2018-06-01/generated/azure_mgmt_data_factory/data_flows.rb', line 23

def client
  @client
end

Instance Method Details

#create_or_update(resource_group_name, factory_name, data_flow_name, data_flow, if_match: nil, custom_headers: nil) ⇒ DataFlowResource

Creates or updates a data flow.

specified for update, for which it should match existing entity or can be * for unconditional update. will be added to the HTTP request.

Parameters:

  • resource_group_name (String)

    The resource group name.

  • factory_name (String)

    The factory name.

  • data_flow_name (String)

    The data flow name.

  • data_flow (DataFlowResource)

    Data flow resource definition.

  • if_match (String) (defaults to: nil)

    ETag of the data flow entity. Should only be

  • custom_headers (Hash{String => String}) (defaults to: nil)

    A hash of custom headers that

Returns:

  • (DataFlowResource)

    operation results.



40
41
42
43
# File 'lib/2018-06-01/generated/azure_mgmt_data_factory/data_flows.rb', line 40

def create_or_update(resource_group_name, factory_name, data_flow_name, data_flow, if_match:nil, custom_headers:nil)
  response = create_or_update_async(resource_group_name, factory_name, data_flow_name, data_flow, if_match:if_match, custom_headers:custom_headers).value!
  response.body unless response.nil?
end

#create_or_update_async(resource_group_name, factory_name, data_flow_name, data_flow, if_match: nil, custom_headers: nil) ⇒ Concurrent::Promise

Creates or updates a data flow.

specified for update, for which it should match existing entity or can be * for unconditional update. to the HTTP request.

Parameters:

  • resource_group_name (String)

    The resource group name.

  • factory_name (String)

    The factory name.

  • data_flow_name (String)

    The data flow name.

  • data_flow (DataFlowResource)

    Data flow resource definition.

  • if_match (String) (defaults to: nil)

    ETag of the data flow entity. Should only be

  • A (Hash{String => String})

    hash of custom headers that will be added

Returns:

  • (Concurrent::Promise)

    Promise object which holds the HTTP response.



79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
# File 'lib/2018-06-01/generated/azure_mgmt_data_factory/data_flows.rb', line 79

def create_or_update_async(resource_group_name, factory_name, data_flow_name, data_flow, if_match:nil, custom_headers:nil)
  fail ArgumentError, '@client.subscription_id is nil' if @client.subscription_id.nil?
  fail ArgumentError, 'resource_group_name is nil' if resource_group_name.nil?
  fail ArgumentError, "'resource_group_name' should satisfy the constraint - 'MaxLength': '90'" if !resource_group_name.nil? && resource_group_name.length > 90
  fail ArgumentError, "'resource_group_name' should satisfy the constraint - 'MinLength': '1'" if !resource_group_name.nil? && resource_group_name.length < 1
  fail ArgumentError, "'resource_group_name' should satisfy the constraint - 'Pattern': '^[-\w\._\(\)]+$'" if !resource_group_name.nil? && resource_group_name.match(Regexp.new('^^[-\w\._\(\)]+$$')).nil?
  fail ArgumentError, 'factory_name is nil' if factory_name.nil?
  fail ArgumentError, "'factory_name' should satisfy the constraint - 'MaxLength': '63'" if !factory_name.nil? && factory_name.length > 63
  fail ArgumentError, "'factory_name' should satisfy the constraint - 'MinLength': '3'" if !factory_name.nil? && factory_name.length < 3
  fail ArgumentError, "'factory_name' should satisfy the constraint - 'Pattern': '^[A-Za-z0-9]+(?:-[A-Za-z0-9]+)*$'" if !factory_name.nil? && factory_name.match(Regexp.new('^^[A-Za-z0-9]+(?:-[A-Za-z0-9]+)*$$')).nil?
  fail ArgumentError, 'data_flow_name is nil' if data_flow_name.nil?
  fail ArgumentError, "'data_flow_name' should satisfy the constraint - 'MaxLength': '260'" if !data_flow_name.nil? && data_flow_name.length > 260
  fail ArgumentError, "'data_flow_name' should satisfy the constraint - 'MinLength': '1'" if !data_flow_name.nil? && data_flow_name.length < 1
  fail ArgumentError, "'data_flow_name' should satisfy the constraint - 'Pattern': '^[A-Za-z0-9_][^<>*#.%&:\\+?/]*$'" if !data_flow_name.nil? && data_flow_name.match(Regexp.new('^^[A-Za-z0-9_][^<>*#.%&:\\+?/]*$$')).nil?
  fail ArgumentError, '@client.api_version is nil' if @client.api_version.nil?
  fail ArgumentError, 'data_flow is nil' if data_flow.nil?


  request_headers = {}
  request_headers['Content-Type'] = 'application/json; charset=utf-8'

  # Set Headers
  request_headers['x-ms-client-request-id'] = SecureRandom.uuid
  request_headers['If-Match'] = if_match unless if_match.nil?
  request_headers['accept-language'] = @client.accept_language unless @client.accept_language.nil?

  # Serialize Request
  request_mapper = Azure::DataFactory::Mgmt::V2018_06_01::Models::DataFlowResource.mapper()
  request_content = @client.serialize(request_mapper,  data_flow)
  request_content = request_content != nil ? JSON.generate(request_content, quirks_mode: true) : nil

  path_template = 'subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.DataFactory/factories/{factoryName}/dataflows/{dataFlowName}'

  request_url = @base_url || @client.base_url

  options = {
      middlewares: [[MsRest::RetryPolicyMiddleware, times: 3, retry: 0.02], [:cookie_jar]],
      path_params: {'subscriptionId' => @client.subscription_id,'resourceGroupName' => resource_group_name,'factoryName' => factory_name,'dataFlowName' => data_flow_name},
      query_params: {'api-version' => @client.api_version},
      body: request_content,
      headers: request_headers.merge(custom_headers || {}),
      base_url: request_url
  }
  promise = @client.make_request_async(:put, path_template, options)

  promise = promise.then do |result|
    http_response = result.response
    status_code = http_response.status
    response_content = http_response.body
    unless status_code == 200
      error_model = JSON.load(response_content)
      fail MsRestAzure::AzureOperationError.new(result.request, http_response, error_model)
    end

    result.request_id = http_response['x-ms-request-id'] unless http_response['x-ms-request-id'].nil?
    result.correlation_request_id = http_response['x-ms-correlation-request-id'] unless http_response['x-ms-correlation-request-id'].nil?
    result.client_request_id = http_response['x-ms-client-request-id'] unless http_response['x-ms-client-request-id'].nil?
    # Deserialize Response
    if status_code == 200
      begin
        parsed_response = response_content.to_s.empty? ? nil : JSON.load(response_content)
        result_mapper = Azure::DataFactory::Mgmt::V2018_06_01::Models::DataFlowResource.mapper()
        result.body = @client.deserialize(result_mapper, parsed_response)
      rescue Exception => e
        fail MsRest::DeserializationError.new('Error occurred in deserializing the response', e.message, e.backtrace, result)
      end
    end

    result
  end

  promise.execute
end

#create_or_update_with_http_info(resource_group_name, factory_name, data_flow_name, data_flow, if_match: nil, custom_headers: nil) ⇒ MsRestAzure::AzureOperationResponse

Creates or updates a data flow.

specified for update, for which it should match existing entity or can be * for unconditional update. will be added to the HTTP request.

Parameters:

  • resource_group_name (String)

    The resource group name.

  • factory_name (String)

    The factory name.

  • data_flow_name (String)

    The data flow name.

  • data_flow (DataFlowResource)

    Data flow resource definition.

  • if_match (String) (defaults to: nil)

    ETag of the data flow entity. Should only be

  • custom_headers (Hash{String => String}) (defaults to: nil)

    A hash of custom headers that

Returns:

  • (MsRestAzure::AzureOperationResponse)

    HTTP response information.



60
61
62
# File 'lib/2018-06-01/generated/azure_mgmt_data_factory/data_flows.rb', line 60

def create_or_update_with_http_info(resource_group_name, factory_name, data_flow_name, data_flow, if_match:nil, custom_headers:nil)
  create_or_update_async(resource_group_name, factory_name, data_flow_name, data_flow, if_match:if_match, custom_headers:custom_headers).value!
end

#delete(resource_group_name, factory_name, data_flow_name, custom_headers: nil) ⇒ Object

Deletes a data flow.

will be added to the HTTP request.

Parameters:

  • resource_group_name (String)

    The resource group name.

  • factory_name (String)

    The factory name.

  • data_flow_name (String)

    The data flow name.

  • custom_headers (Hash{String => String}) (defaults to: nil)

    A hash of custom headers that



280
281
282
283
# File 'lib/2018-06-01/generated/azure_mgmt_data_factory/data_flows.rb', line 280

def delete(resource_group_name, factory_name, data_flow_name, custom_headers:nil)
  response = delete_async(resource_group_name, factory_name, data_flow_name, custom_headers:custom_headers).value!
  nil
end

#delete_async(resource_group_name, factory_name, data_flow_name, custom_headers: nil) ⇒ Concurrent::Promise

Deletes a data flow.

to the HTTP request.

Parameters:

  • resource_group_name (String)

    The resource group name.

  • factory_name (String)

    The factory name.

  • data_flow_name (String)

    The data flow name.

  • A (Hash{String => String})

    hash of custom headers that will be added

Returns:

  • (Concurrent::Promise)

    Promise object which holds the HTTP response.



311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
# File 'lib/2018-06-01/generated/azure_mgmt_data_factory/data_flows.rb', line 311

def delete_async(resource_group_name, factory_name, data_flow_name, custom_headers:nil)
  fail ArgumentError, '@client.subscription_id is nil' if @client.subscription_id.nil?
  fail ArgumentError, 'resource_group_name is nil' if resource_group_name.nil?
  fail ArgumentError, "'resource_group_name' should satisfy the constraint - 'MaxLength': '90'" if !resource_group_name.nil? && resource_group_name.length > 90
  fail ArgumentError, "'resource_group_name' should satisfy the constraint - 'MinLength': '1'" if !resource_group_name.nil? && resource_group_name.length < 1
  fail ArgumentError, "'resource_group_name' should satisfy the constraint - 'Pattern': '^[-\w\._\(\)]+$'" if !resource_group_name.nil? && resource_group_name.match(Regexp.new('^^[-\w\._\(\)]+$$')).nil?
  fail ArgumentError, 'factory_name is nil' if factory_name.nil?
  fail ArgumentError, "'factory_name' should satisfy the constraint - 'MaxLength': '63'" if !factory_name.nil? && factory_name.length > 63
  fail ArgumentError, "'factory_name' should satisfy the constraint - 'MinLength': '3'" if !factory_name.nil? && factory_name.length < 3
  fail ArgumentError, "'factory_name' should satisfy the constraint - 'Pattern': '^[A-Za-z0-9]+(?:-[A-Za-z0-9]+)*$'" if !factory_name.nil? && factory_name.match(Regexp.new('^^[A-Za-z0-9]+(?:-[A-Za-z0-9]+)*$$')).nil?
  fail ArgumentError, 'data_flow_name is nil' if data_flow_name.nil?
  fail ArgumentError, "'data_flow_name' should satisfy the constraint - 'MaxLength': '260'" if !data_flow_name.nil? && data_flow_name.length > 260
  fail ArgumentError, "'data_flow_name' should satisfy the constraint - 'MinLength': '1'" if !data_flow_name.nil? && data_flow_name.length < 1
  fail ArgumentError, "'data_flow_name' should satisfy the constraint - 'Pattern': '^[A-Za-z0-9_][^<>*#.%&:\\+?/]*$'" if !data_flow_name.nil? && data_flow_name.match(Regexp.new('^^[A-Za-z0-9_][^<>*#.%&:\\+?/]*$$')).nil?
  fail ArgumentError, '@client.api_version is nil' if @client.api_version.nil?


  request_headers = {}
  request_headers['Content-Type'] = 'application/json; charset=utf-8'

  # Set Headers
  request_headers['x-ms-client-request-id'] = SecureRandom.uuid
  request_headers['accept-language'] = @client.accept_language unless @client.accept_language.nil?
  path_template = 'subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.DataFactory/factories/{factoryName}/dataflows/{dataFlowName}'

  request_url = @base_url || @client.base_url

  options = {
      middlewares: [[MsRest::RetryPolicyMiddleware, times: 3, retry: 0.02], [:cookie_jar]],
      path_params: {'subscriptionId' => @client.subscription_id,'resourceGroupName' => resource_group_name,'factoryName' => factory_name,'dataFlowName' => data_flow_name},
      query_params: {'api-version' => @client.api_version},
      headers: request_headers.merge(custom_headers || {}),
      base_url: request_url
  }
  promise = @client.make_request_async(:delete, path_template, options)

  promise = promise.then do |result|
    http_response = result.response
    status_code = http_response.status
    response_content = http_response.body
    unless status_code == 200 || status_code == 204
      error_model = JSON.load(response_content)
      fail MsRestAzure::AzureOperationError.new(result.request, http_response, error_model)
    end

    result.request_id = http_response['x-ms-request-id'] unless http_response['x-ms-request-id'].nil?
    result.correlation_request_id = http_response['x-ms-correlation-request-id'] unless http_response['x-ms-correlation-request-id'].nil?
    result.client_request_id = http_response['x-ms-client-request-id'] unless http_response['x-ms-client-request-id'].nil?

    result
  end

  promise.execute
end

#delete_with_http_info(resource_group_name, factory_name, data_flow_name, custom_headers: nil) ⇒ MsRestAzure::AzureOperationResponse

Deletes a data flow.

will be added to the HTTP request.

Parameters:

  • resource_group_name (String)

    The resource group name.

  • factory_name (String)

    The factory name.

  • data_flow_name (String)

    The data flow name.

  • custom_headers (Hash{String => String}) (defaults to: nil)

    A hash of custom headers that

Returns:

  • (MsRestAzure::AzureOperationResponse)

    HTTP response information.



296
297
298
# File 'lib/2018-06-01/generated/azure_mgmt_data_factory/data_flows.rb', line 296

def delete_with_http_info(resource_group_name, factory_name, data_flow_name, custom_headers:nil)
  delete_async(resource_group_name, factory_name, data_flow_name, custom_headers:custom_headers).value!
end

#get(resource_group_name, factory_name, data_flow_name, if_none_match: nil, custom_headers: nil) ⇒ DataFlowResource

Gets a data flow.

specified for get. If the ETag matches the existing entity tag, or if * was provided, then no content will be returned. will be added to the HTTP request.

Parameters:

  • resource_group_name (String)

    The resource group name.

  • factory_name (String)

    The factory name.

  • data_flow_name (String)

    The data flow name.

  • if_none_match (String) (defaults to: nil)

    ETag of the data flow entity. Should only be

  • custom_headers (Hash{String => String}) (defaults to: nil)

    A hash of custom headers that

Returns:

  • (DataFlowResource)

    operation results.



167
168
169
170
# File 'lib/2018-06-01/generated/azure_mgmt_data_factory/data_flows.rb', line 167

def get(resource_group_name, factory_name, data_flow_name, if_none_match:nil, custom_headers:nil)
  response = get_async(resource_group_name, factory_name, data_flow_name, if_none_match:if_none_match, custom_headers:custom_headers).value!
  response.body unless response.nil?
end

#get_async(resource_group_name, factory_name, data_flow_name, if_none_match: nil, custom_headers: nil) ⇒ Concurrent::Promise

Gets a data flow.

specified for get. If the ETag matches the existing entity tag, or if * was provided, then no content will be returned. to the HTTP request.

Parameters:

  • resource_group_name (String)

    The resource group name.

  • factory_name (String)

    The factory name.

  • data_flow_name (String)

    The data flow name.

  • if_none_match (String) (defaults to: nil)

    ETag of the data flow entity. Should only be

  • A (Hash{String => String})

    hash of custom headers that will be added

Returns:

  • (Concurrent::Promise)

    Promise object which holds the HTTP response.



204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
# File 'lib/2018-06-01/generated/azure_mgmt_data_factory/data_flows.rb', line 204

def get_async(resource_group_name, factory_name, data_flow_name, if_none_match:nil, custom_headers:nil)
  fail ArgumentError, '@client.subscription_id is nil' if @client.subscription_id.nil?
  fail ArgumentError, 'resource_group_name is nil' if resource_group_name.nil?
  fail ArgumentError, "'resource_group_name' should satisfy the constraint - 'MaxLength': '90'" if !resource_group_name.nil? && resource_group_name.length > 90
  fail ArgumentError, "'resource_group_name' should satisfy the constraint - 'MinLength': '1'" if !resource_group_name.nil? && resource_group_name.length < 1
  fail ArgumentError, "'resource_group_name' should satisfy the constraint - 'Pattern': '^[-\w\._\(\)]+$'" if !resource_group_name.nil? && resource_group_name.match(Regexp.new('^^[-\w\._\(\)]+$$')).nil?
  fail ArgumentError, 'factory_name is nil' if factory_name.nil?
  fail ArgumentError, "'factory_name' should satisfy the constraint - 'MaxLength': '63'" if !factory_name.nil? && factory_name.length > 63
  fail ArgumentError, "'factory_name' should satisfy the constraint - 'MinLength': '3'" if !factory_name.nil? && factory_name.length < 3
  fail ArgumentError, "'factory_name' should satisfy the constraint - 'Pattern': '^[A-Za-z0-9]+(?:-[A-Za-z0-9]+)*$'" if !factory_name.nil? && factory_name.match(Regexp.new('^^[A-Za-z0-9]+(?:-[A-Za-z0-9]+)*$$')).nil?
  fail ArgumentError, 'data_flow_name is nil' if data_flow_name.nil?
  fail ArgumentError, "'data_flow_name' should satisfy the constraint - 'MaxLength': '260'" if !data_flow_name.nil? && data_flow_name.length > 260
  fail ArgumentError, "'data_flow_name' should satisfy the constraint - 'MinLength': '1'" if !data_flow_name.nil? && data_flow_name.length < 1
  fail ArgumentError, "'data_flow_name' should satisfy the constraint - 'Pattern': '^[A-Za-z0-9_][^<>*#.%&:\\+?/]*$'" if !data_flow_name.nil? && data_flow_name.match(Regexp.new('^^[A-Za-z0-9_][^<>*#.%&:\\+?/]*$$')).nil?
  fail ArgumentError, '@client.api_version is nil' if @client.api_version.nil?


  request_headers = {}
  request_headers['Content-Type'] = 'application/json; charset=utf-8'

  # Set Headers
  request_headers['x-ms-client-request-id'] = SecureRandom.uuid
  request_headers['If-None-Match'] = if_none_match unless if_none_match.nil?
  request_headers['accept-language'] = @client.accept_language unless @client.accept_language.nil?
  path_template = 'subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.DataFactory/factories/{factoryName}/dataflows/{dataFlowName}'

  request_url = @base_url || @client.base_url

  options = {
      middlewares: [[MsRest::RetryPolicyMiddleware, times: 3, retry: 0.02], [:cookie_jar]],
      path_params: {'subscriptionId' => @client.subscription_id,'resourceGroupName' => resource_group_name,'factoryName' => factory_name,'dataFlowName' => data_flow_name},
      query_params: {'api-version' => @client.api_version},
      headers: request_headers.merge(custom_headers || {}),
      base_url: request_url
  }
  promise = @client.make_request_async(:get, path_template, options)

  promise = promise.then do |result|
    http_response = result.response
    status_code = http_response.status
    response_content = http_response.body
    unless status_code == 200
      error_model = JSON.load(response_content)
      fail MsRestAzure::AzureOperationError.new(result.request, http_response, error_model)
    end

    result.request_id = http_response['x-ms-request-id'] unless http_response['x-ms-request-id'].nil?
    result.correlation_request_id = http_response['x-ms-correlation-request-id'] unless http_response['x-ms-correlation-request-id'].nil?
    result.client_request_id = http_response['x-ms-client-request-id'] unless http_response['x-ms-client-request-id'].nil?
    # Deserialize Response
    if status_code == 200
      begin
        parsed_response = response_content.to_s.empty? ? nil : JSON.load(response_content)
        result_mapper = Azure::DataFactory::Mgmt::V2018_06_01::Models::DataFlowResource.mapper()
        result.body = @client.deserialize(result_mapper, parsed_response)
      rescue Exception => e
        fail MsRest::DeserializationError.new('Error occurred in deserializing the response', e.message, e.backtrace, result)
      end
    end

    result
  end

  promise.execute
end

#get_with_http_info(resource_group_name, factory_name, data_flow_name, if_none_match: nil, custom_headers: nil) ⇒ MsRestAzure::AzureOperationResponse

Gets a data flow.

specified for get. If the ETag matches the existing entity tag, or if * was provided, then no content will be returned. will be added to the HTTP request.

Parameters:

  • resource_group_name (String)

    The resource group name.

  • factory_name (String)

    The factory name.

  • data_flow_name (String)

    The data flow name.

  • if_none_match (String) (defaults to: nil)

    ETag of the data flow entity. Should only be

  • custom_headers (Hash{String => String}) (defaults to: nil)

    A hash of custom headers that

Returns:

  • (MsRestAzure::AzureOperationResponse)

    HTTP response information.



186
187
188
# File 'lib/2018-06-01/generated/azure_mgmt_data_factory/data_flows.rb', line 186

def get_with_http_info(resource_group_name, factory_name, data_flow_name, if_none_match:nil, custom_headers:nil)
  get_async(resource_group_name, factory_name, data_flow_name, if_none_match:if_none_match, custom_headers:custom_headers).value!
end

#list_by_factory(resource_group_name, factory_name, custom_headers: nil) ⇒ Array<DataFlowResource>

Lists data flows.

will be added to the HTTP request.

Parameters:

  • resource_group_name (String)

    The resource group name.

  • factory_name (String)

    The factory name.

  • custom_headers (Hash{String => String}) (defaults to: nil)

    A hash of custom headers that

Returns:

  • (Array<DataFlowResource>)

    operation results.



376
377
378
379
# File 'lib/2018-06-01/generated/azure_mgmt_data_factory/data_flows.rb', line 376

def list_by_factory(resource_group_name, factory_name, custom_headers:nil)
  first_page = list_by_factory_as_lazy(resource_group_name, factory_name, custom_headers:custom_headers)
  first_page.get_all_items
end

#list_by_factory_as_lazy(resource_group_name, factory_name, custom_headers: nil) ⇒ DataFlowListResponse

Lists data flows.

will be added to the HTTP request.

response.

Parameters:

  • resource_group_name (String)

    The resource group name.

  • factory_name (String)

    The factory name.

  • custom_headers (Hash{String => String}) (defaults to: nil)

    A hash of custom headers that

Returns:

  • (DataFlowListResponse)

    which provide lazy access to pages of the



567
568
569
570
571
572
573
574
575
576
# File 'lib/2018-06-01/generated/azure_mgmt_data_factory/data_flows.rb', line 567

def list_by_factory_as_lazy(resource_group_name, factory_name, custom_headers:nil)
  response = list_by_factory_async(resource_group_name, factory_name, custom_headers:custom_headers).value!
  unless response.nil?
    page = response.body
    page.next_method = Proc.new do |next_page_link|
      list_by_factory_next_async(next_page_link, custom_headers:custom_headers)
    end
    page
  end
end

#list_by_factory_async(resource_group_name, factory_name, custom_headers: nil) ⇒ Concurrent::Promise

Lists data flows.

to the HTTP request.

Parameters:

  • resource_group_name (String)

    The resource group name.

  • factory_name (String)

    The factory name.

  • A (Hash{String => String})

    hash of custom headers that will be added

Returns:

  • (Concurrent::Promise)

    Promise object which holds the HTTP response.



405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
# File 'lib/2018-06-01/generated/azure_mgmt_data_factory/data_flows.rb', line 405

def list_by_factory_async(resource_group_name, factory_name, custom_headers:nil)
  fail ArgumentError, '@client.subscription_id is nil' if @client.subscription_id.nil?
  fail ArgumentError, 'resource_group_name is nil' if resource_group_name.nil?
  fail ArgumentError, "'resource_group_name' should satisfy the constraint - 'MaxLength': '90'" if !resource_group_name.nil? && resource_group_name.length > 90
  fail ArgumentError, "'resource_group_name' should satisfy the constraint - 'MinLength': '1'" if !resource_group_name.nil? && resource_group_name.length < 1
  fail ArgumentError, "'resource_group_name' should satisfy the constraint - 'Pattern': '^[-\w\._\(\)]+$'" if !resource_group_name.nil? && resource_group_name.match(Regexp.new('^^[-\w\._\(\)]+$$')).nil?
  fail ArgumentError, 'factory_name is nil' if factory_name.nil?
  fail ArgumentError, "'factory_name' should satisfy the constraint - 'MaxLength': '63'" if !factory_name.nil? && factory_name.length > 63
  fail ArgumentError, "'factory_name' should satisfy the constraint - 'MinLength': '3'" if !factory_name.nil? && factory_name.length < 3
  fail ArgumentError, "'factory_name' should satisfy the constraint - 'Pattern': '^[A-Za-z0-9]+(?:-[A-Za-z0-9]+)*$'" if !factory_name.nil? && factory_name.match(Regexp.new('^^[A-Za-z0-9]+(?:-[A-Za-z0-9]+)*$$')).nil?
  fail ArgumentError, '@client.api_version is nil' if @client.api_version.nil?


  request_headers = {}
  request_headers['Content-Type'] = 'application/json; charset=utf-8'

  # Set Headers
  request_headers['x-ms-client-request-id'] = SecureRandom.uuid
  request_headers['accept-language'] = @client.accept_language unless @client.accept_language.nil?
  path_template = 'subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.DataFactory/factories/{factoryName}/dataflows'

  request_url = @base_url || @client.base_url

  options = {
      middlewares: [[MsRest::RetryPolicyMiddleware, times: 3, retry: 0.02], [:cookie_jar]],
      path_params: {'subscriptionId' => @client.subscription_id,'resourceGroupName' => resource_group_name,'factoryName' => factory_name},
      query_params: {'api-version' => @client.api_version},
      headers: request_headers.merge(custom_headers || {}),
      base_url: request_url
  }
  promise = @client.make_request_async(:get, path_template, options)

  promise = promise.then do |result|
    http_response = result.response
    status_code = http_response.status
    response_content = http_response.body
    unless status_code == 200
      error_model = JSON.load(response_content)
      fail MsRestAzure::AzureOperationError.new(result.request, http_response, error_model)
    end

    result.request_id = http_response['x-ms-request-id'] unless http_response['x-ms-request-id'].nil?
    result.correlation_request_id = http_response['x-ms-correlation-request-id'] unless http_response['x-ms-correlation-request-id'].nil?
    result.client_request_id = http_response['x-ms-client-request-id'] unless http_response['x-ms-client-request-id'].nil?
    # Deserialize Response
    if status_code == 200
      begin
        parsed_response = response_content.to_s.empty? ? nil : JSON.load(response_content)
        result_mapper = Azure::DataFactory::Mgmt::V2018_06_01::Models::DataFlowListResponse.mapper()
        result.body = @client.deserialize(result_mapper, parsed_response)
      rescue Exception => e
        fail MsRest::DeserializationError.new('Error occurred in deserializing the response', e.message, e.backtrace, result)
      end
    end

    result
  end

  promise.execute
end

#list_by_factory_next(next_page_link, custom_headers: nil) ⇒ DataFlowListResponse

Lists data flows.

to List operation. will be added to the HTTP request.

Parameters:

  • next_page_link (String)

    The NextLink from the previous successful call

  • custom_headers (Hash{String => String}) (defaults to: nil)

    A hash of custom headers that

Returns:

  • (DataFlowListResponse)

    operation results.



476
477
478
479
# File 'lib/2018-06-01/generated/azure_mgmt_data_factory/data_flows.rb', line 476

def list_by_factory_next(next_page_link, custom_headers:nil)
  response = list_by_factory_next_async(next_page_link, custom_headers:custom_headers).value!
  response.body unless response.nil?
end

#list_by_factory_next_async(next_page_link, custom_headers: nil) ⇒ Concurrent::Promise

Lists data flows.

to List operation. to the HTTP request.

Parameters:

  • next_page_link (String)

    The NextLink from the previous successful call

  • A (Hash{String => String})

    hash of custom headers that will be added

Returns:

  • (Concurrent::Promise)

    Promise object which holds the HTTP response.



505
506
507
508
509
510
511
512
513
514
515
516
517
518
519
520
521
522
523
524
525
526
527
528
529
530
531
532
533
534
535
536
537
538
539
540
541
542
543
544
545
546
547
548
549
550
551
552
553
554
# File 'lib/2018-06-01/generated/azure_mgmt_data_factory/data_flows.rb', line 505

def list_by_factory_next_async(next_page_link, custom_headers:nil)
  fail ArgumentError, 'next_page_link is nil' if next_page_link.nil?


  request_headers = {}
  request_headers['Content-Type'] = 'application/json; charset=utf-8'

  # Set Headers
  request_headers['x-ms-client-request-id'] = SecureRandom.uuid
  request_headers['accept-language'] = @client.accept_language unless @client.accept_language.nil?
  path_template = '{nextLink}'

  request_url = @base_url || @client.base_url

  options = {
      middlewares: [[MsRest::RetryPolicyMiddleware, times: 3, retry: 0.02], [:cookie_jar]],
      skip_encoding_path_params: {'nextLink' => next_page_link},
      headers: request_headers.merge(custom_headers || {}),
      base_url: request_url
  }
  promise = @client.make_request_async(:get, path_template, options)

  promise = promise.then do |result|
    http_response = result.response
    status_code = http_response.status
    response_content = http_response.body
    unless status_code == 200
      error_model = JSON.load(response_content)
      fail MsRestAzure::AzureOperationError.new(result.request, http_response, error_model)
    end

    result.request_id = http_response['x-ms-request-id'] unless http_response['x-ms-request-id'].nil?
    result.correlation_request_id = http_response['x-ms-correlation-request-id'] unless http_response['x-ms-correlation-request-id'].nil?
    result.client_request_id = http_response['x-ms-client-request-id'] unless http_response['x-ms-client-request-id'].nil?
    # Deserialize Response
    if status_code == 200
      begin
        parsed_response = response_content.to_s.empty? ? nil : JSON.load(response_content)
        result_mapper = Azure::DataFactory::Mgmt::V2018_06_01::Models::DataFlowListResponse.mapper()
        result.body = @client.deserialize(result_mapper, parsed_response)
      rescue Exception => e
        fail MsRest::DeserializationError.new('Error occurred in deserializing the response', e.message, e.backtrace, result)
      end
    end

    result
  end

  promise.execute
end

#list_by_factory_next_with_http_info(next_page_link, custom_headers: nil) ⇒ MsRestAzure::AzureOperationResponse

Lists data flows.

to List operation. will be added to the HTTP request.

Parameters:

  • next_page_link (String)

    The NextLink from the previous successful call

  • custom_headers (Hash{String => String}) (defaults to: nil)

    A hash of custom headers that

Returns:

  • (MsRestAzure::AzureOperationResponse)

    HTTP response information.



491
492
493
# File 'lib/2018-06-01/generated/azure_mgmt_data_factory/data_flows.rb', line 491

def list_by_factory_next_with_http_info(next_page_link, custom_headers:nil)
  list_by_factory_next_async(next_page_link, custom_headers:custom_headers).value!
end

#list_by_factory_with_http_info(resource_group_name, factory_name, custom_headers: nil) ⇒ MsRestAzure::AzureOperationResponse

Lists data flows.

will be added to the HTTP request.

Parameters:

  • resource_group_name (String)

    The resource group name.

  • factory_name (String)

    The factory name.

  • custom_headers (Hash{String => String}) (defaults to: nil)

    A hash of custom headers that

Returns:

  • (MsRestAzure::AzureOperationResponse)

    HTTP response information.



391
392
393
# File 'lib/2018-06-01/generated/azure_mgmt_data_factory/data_flows.rb', line 391

def list_by_factory_with_http_info(resource_group_name, factory_name, custom_headers:nil)
  list_by_factory_async(resource_group_name, factory_name, custom_headers:custom_headers).value!
end